@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmain.php,v 1.137 2012/05/26 20:05:56 gruberroland Exp $
+$Id: confmain.php,v 1.139 2012/11/02 18:15:17 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2012  Roland Gruber
@@ -129,8 +129,16 @@ echo ("<title>" . _("LDAP Account Manager Configuration") . "</title>\n");
 // include all CSS files
 $cssDirName = dirname(__FILE__) . '/../../style';
 $cssDir = dir($cssDirName);
-while ($cssEntry = $cssDir->read()) {
-	if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+$cssFiles = array();
+$cssEntry = $cssDir->read();
+while ($cssEntry !== false) {
+	if (substr($cssEntry, strlen($cssEntry) - 4, 4) == '.css') {
+		$cssFiles[] = $cssEntry;
+	}
+	$cssEntry = $cssDir->read();
+}
+sort($cssFiles);
+foreach ($cssFiles as $cssEntry) {
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
 }
 
@@ -155,6 +163,10 @@ foreach ($jsFiles as $jsEntry) {
 				<td align="left" height="30">
 					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
 				</td>
+				<td align="right">
+					<?php echo _('Server profile') . ': ' . $conf->getName(); ?>
+					&nbsp;&nbsp;
+				</td>
 			</tr>
 		</table>
 		<br>
