@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmodules.php,v 1.45 2012/07/22 18:10:44 gruberroland Exp $
+$Id: confmodules.php,v 1.47 2012/11/02 18:15:17 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2011  Roland Gruber
+  Copyright (C) 2004 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -99,15 +99,20 @@ echo "<title>" . _("LDAP Account Manager Configuration") . "</title>\n";
 // include all CSS files
 $cssDirName = dirname(__FILE__) . '/../../style';
 $cssDir = dir($cssDirName);
-while ($cssEntry = $cssDir->read()) {
-	if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+$cssFiles = array();
+$cssEntry = $cssDir->read();
+while ($cssEntry !== false) {
+	if (substr($cssEntry, strlen($cssEntry) - 4, 4) == '.css') {
+		$cssFiles[] = $cssEntry;
+	}
+	$cssEntry = $cssDir->read();
+}
+sort($cssFiles);
+foreach ($cssFiles as $cssEntry) {
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
 }
 
 echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
-for ($i = 0; $i < sizeof($types); $i++){
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $types[$i] . ".css\">\n";
-}
 echo "</head><body>\n";
 // include all JavaScript files
 $jsDirName = dirname(__FILE__) . '/../lib';
@@ -128,6 +133,10 @@ foreach ($jsFiles as $jsEntry) {
 				<td align="left" height="30">
 					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
 				</td>
+				<td align="right">
+					<?php echo _('Server profile') . ': ' . $conf->getName(); ?>
+					&nbsp;&nbsp;
+				</td>
 			</tr>
 		</table>
 		<br>
