@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: mainmanage.php,v 1.28 2012/03/13 21:02:37 gruberroland Exp $
+$Id: mainmanage.php,v 1.29 2012/11/02 17:45:35 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2012  Roland Gruber
@@ -138,8 +138,16 @@ echo $_SESSION['header'];
 		// include all CSS files
 		$cssDirName = dirname(__FILE__) . '/../../style';
 		$cssDir = dir($cssDirName);
-		while ($cssEntry = $cssDir->read()) {
-			if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+		$cssFiles = array();
+		$cssEntry = $cssDir->read();
+		while ($cssEntry !== false) {
+			if (substr($cssEntry, strlen($cssEntry) - 4, 4) == '.css') {
+				$cssFiles[] = $cssEntry;
+			}
+			$cssEntry = $cssDir->read();
+		}
+		sort($cssFiles);
+		foreach ($cssFiles as $cssEntry) {
 			echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
 		}
 	?>
