@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profmanage.php,v 1.46 2012/04/09 13:20:24 gruberroland Exp $
+$Id: profmanage.php,v 1.48 2012/11/02 17:45:35 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2012  Roland Gruber
@@ -89,6 +89,10 @@ if (isset($_POST['action'])) {
 	elseif ($_POST['action'] == "rename") {
 		if (preg_match("/^[a-z0-9_-]+$/i", $_POST['oldfilename']) && preg_match("/^[a-z0-9_-]+$/i", $_POST['renfilename']) && !in_array($_POST['renfilename'], getConfigProfiles())) {
 			if (rename("../../config/" . $_POST['oldfilename'] . ".conf", "../../config/" . $_POST['renfilename'] . ".conf")) {
+			    // rename pdf and profiles folder
+			    rename("../../config/profiles/" . $_POST['oldfilename'], "../../config/profiles/" . $_POST['renfilename']);
+			    rename("../../config/pdf/" . $_POST['oldfilename'], "../../config/pdf/" . $_POST['renfilename']);
+
 				$msg = _("Renamed profile.");
 			}
 			else $error = _("Could not rename file!");
@@ -102,7 +106,7 @@ if (isset($_POST['action'])) {
 	}
 	// delete profile
 	elseif ($_POST['action'] == "delete") {
-		if (preg_match("/^[a-z0-9_-]+$/i", $_POST['delfilename']) && @unlink("../../config/" . $_POST['delfilename'] . ".conf")) {
+		if (deleteConfigProfile($_POST['delfilename']) == null) {
 			$msg = _("Profile deleted.");
 		}
 		else $error = _("Unable to delete profile!");
@@ -148,8 +152,16 @@ echo $_SESSION['header'];
 		// include all CSS files
 		$cssDirName = dirname(__FILE__) . '/../../style';
 		$cssDir = dir($cssDirName);
-		while ($cssEntry = $cssDir->read()) {
-			if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+		$cssFiles = array();
+		$cssEntry = $cssDir->read();
+		while ($cssEntry !== false) {
+			if (substr($cssEntry, strlen($cssEntry) - 4, 4) == '.css') {
+				$cssFiles[] = $cssEntry;
+			}
+			$cssEntry = $cssDir->read();
+		}
+		sort($cssFiles);
+		foreach ($cssFiles as $cssEntry) {
 			echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
 		}
 	?>
