@@ -1,6 +1,6 @@
 /**
 
-$Id: 500_lam.js,v 1.17 2012/09/09 14:02:27 gruberroland Exp $
+$Id: 500_lam.js,v 1.18 2012/10/28 14:29:01 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2012  Roland Gruber
@@ -320,3 +320,70 @@ function showConfirmationDialog(title, okText, cancelText, dialogDiv, formName,
 	jQuery('#' + dialogDiv).parent().appendTo(document.forms[formName]);
 }
 
+/**
+ * Alines the elements with the given IDs to the same width.
+ * 
+ * @param elementIDs IDs
+ */
+function equalWidth(elementIDs) {
+	var maxWidth = 0;
+	for (var i = 0; i < elementIDs.length; ++i) {
+		if (jQuery(elementIDs[i]).width() > maxWidth) {
+			maxWidth = jQuery(elementIDs[i]).width();
+		};
+	}
+	for (var i = 0; i < elementIDs.length; ++i) {
+		jQuery(elementIDs[i]).css({'width': maxWidth - (jQuery(elementIDs[i]).outerWidth() - jQuery(elementIDs[i]).width())});
+	}
+}
+
+/**
+ * Shows the dialog to change the list settings.
+ * 
+ * @param title dialog title
+ * @param okText text for Ok button
+ * @param cancelText text for Cancel button
+ * @param scope account type
+ * @param selectFieldName name of select box with profile name
+ * @param serverProfile profile name
+ */
+function showDistributionDialog(title, okText, cancelText, scope, type, selectFieldName, serverProfile) {
+	// show dialog
+	var buttonList = {};
+	var dialogId = '';
+	buttonList[cancelText] = function() { jQuery(this).dialog("close"); };
+	
+	if (type == 'export') {
+		// show structure name to export
+		jQuery('#exportName').text(jQuery('[name=' + selectFieldName + ']').val());
+		dialogId = 'exportDialog';
+		buttonList[okText] = function() { document.forms["exportDialogForm"].submit(); };
+		jQuery('<input>').attr({
+		    type: 'hidden',
+		    name: 'exportProfiles[]',
+		    value: serverProfile + '##' + jQuery('[name=' + selectFieldName + ']').val()
+		}).appendTo('form');
+		jQuery('<input>').attr({
+		    type: 'hidden',
+		    name: 'scope',
+		    value: scope
+		}).appendTo('form');
+	} else if (type == 'import') {
+		dialogId = 'importDialog_' + scope;
+		buttonList[okText] = function() { document.forms["importDialogForm_" + scope].submit(); };
+	}
+	
+	jQuery('#' + dialogId).dialog({
+		modal: true,
+		title: title,
+		dialogClass: 'defaultBackground',
+		buttons: buttonList,
+		width: 'auto'
+	});
+	if (type == 'export') {
+		equalWidth(new Array('#passwd', '#destServerProfiles'));
+	} else if (type == 'import') {
+		equalWidth(new Array('#passwd_' + scope, '#importProfiles_' + scope));
+	}
+}
+
