@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: list.php,v 1.5 2009/10/27 18:46:33 gruberroland Exp $
+$Id: list.php,v 1.6 2013/01/01 20:46:27 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2006  Roland Gruber
+  Copyright (C) 2003 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,9 +41,15 @@ startSecureSession();
 
 setlanguage();
 
+$type = $_GET['type'];
+
+// check if list is hidden
+if (isAccountTypeHidden($type)) {
+	logNewMessage(LOG_ERR, 'User tried to access hidden account list: ' . $type);
+	die();
+}
 
 // create list object if needed
-$type = $_GET['type'];
 $listClass = getListClassName($type);
 if (!isset($_SESSION['list_' . $type])) {
 	$list = new $listClass($type);
