@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: userlink.php,v 1.26 2010/08/21 09:43:51 gruberroland Exp $
+$Id: userlink.php,v 1.27 2012/03/18 18:31:36 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -58,7 +58,7 @@ if ($dn) {
 else {
 	// print error message if user was not found
 	include '../main_header.php';
-	StatusMessage("ERROR", "", _("This user was not found!") . " (" . $user . ")");
+	StatusMessage("ERROR", "", _("This user was not found!") . " (" . htmlspecialchars($user) . ")");
 	echo "<p>&nbsp;</p>";
 	echo "<p><a href=\"list.php?type=group\">" . _("Back to group list") . "</a></p>";
 	include '../main_footer.php';
