@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: login.php,v 1.151 2012/09/13 20:08:36 gruberroland Exp $
+$Id: login.php,v 1.158 2013/01/05 16:22:58 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-                2005 - 2012  Roland Gruber
+                2005 - 2013  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,6 +43,9 @@ include_once("../lib/selfService.inc");
 /** access to configuration options */
 include_once("../lib/config.inc"); // Include config.inc which provides Config class
 
+/** Upgrade functions */
+include_once("../lib/upgrade.inc");
+
 // set session save path
 if (strtolower(session_module_name()) == 'files') {
 	session_save_path(dirname(__FILE__) . '/../sess');
@@ -77,11 +80,16 @@ if(isset($_GET['useProfile'])) {
 	$_SESSION['config'] = new LAMConfig($_GET['useProfile']); // Recreate the config object with the submited
 }
 // Load login page
-else {
+elseif (!empty($default_Profile)) {
 	$_SESSION["config"] = new LAMConfig($default_Profile); // Create new Config object
 }
 
-$_SESSION['language'] = $_SESSION["config"]->get_defaultLanguage();
+if (!empty($_SESSION["config"])) {
+	$_SESSION['language'] = $_SESSION["config"]->get_defaultLanguage();
+}
+else {
+	$_SESSION['language'] = 'en_GB.utf8:UTF-8:English (Great Britain)';
+}
 if (isset($_POST['language'])) {
 	$_SESSION['language'] = $_POST['language']; // Write selected language in session
 }
@@ -91,7 +99,6 @@ $_SESSION['header'] .= "<html>\n<head>\n";
 $_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $current_language[1] . "\">\n";
 $_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
 
-
 /**
 * Displays the login window.
 *
@@ -154,8 +161,16 @@ function display_LoginPage($config_object) {
 		// include all CSS files
 		$cssDirName = dirname(__FILE__) . '/../style';
 		$cssDir = dir($cssDirName);
-		while ($cssEntry = $cssDir->read()) {
-			if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+		$cssFiles = array();
+		$cssEntry = $cssDir->read();
+		while ($cssEntry !== false) {
+			if (substr($cssEntry, strlen($cssEntry) - 4, 4) == '.css') {
+				$cssFiles[] = $cssEntry;
+			}
+			$cssEntry = $cssDir->read();
+		}
+		sort($cssFiles);
+		foreach ($cssFiles as $cssEntry) {
 			echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/" . $cssEntry . "\">\n";
 		}
 	?>
@@ -176,7 +191,22 @@ function display_LoginPage($config_object) {
 		echo "<script type=\"text/javascript\" src=\"lib/" . $jsEntry . "\"></script>\n";
 	}
 	
+	// upgrade if pdf/profiles contain single files
+	if (containsFiles('../config/profiles') || containsFiles('../config/pdf')) {
+		$result = testPermissions();
+		if (sizeof($result) > 0) {
+		    StatusMessage('ERROR', 'Unable to migrate configuration files. Please allow write access to these paths:', implode('<br>', $result));
+		}
+		else {
+			upgradeConfigToServerProfileFolders(getConfigProfiles());
+			StatusMessage('INFO', 'Config file migration finished.');
+		}
+	}
+	// copy any missing default profiles
+	copyConfigTemplates(getConfigProfiles());
+	
 	// set focus on password field
+	if (!empty($config_object)) {
 		echo "<script type=\"text/javascript\" language=\"javascript\">\n";
 		echo "<!--\n";
 		echo "function focusLogin() {\n";
@@ -196,20 +226,13 @@ function display_LoginPage($config_object) {
 		<?php
 		echo "//-->\n";
 		echo "</script>\n";
+	}
 	?>
 
 		<script type="text/javascript">
 			jQuery(document).ready(function() {
 				var equalWidthElements = new Array('#username', '#passwd', '#language');
-				var maxWidth = 0;
-				for (var i = 0; i < equalWidthElements.length; ++i) {
-					if (jQuery(equalWidthElements[i]).width() > maxWidth) {
-						maxWidth = jQuery(equalWidthElements[i]).width();
-					};
-				}
-				for (var i = 0; i < equalWidthElements.length; ++i) {
-					jQuery(equalWidthElements[i]).css({'width': maxWidth - (jQuery(equalWidthElements[i]).outerWidth() - jQuery(equalWidthElements[i]).width())});
-				}
+				equalWidth(equalWidthElements);
 			});
 		</script>
 
@@ -227,20 +250,22 @@ function display_LoginPage($config_object) {
 		<br><br>
 
 		<?php
-		// check extensions
-		$extList = getRequiredExtensions();
-		for ($i = 0; $i < sizeof($extList); $i++) {
-			if (!extension_loaded($extList[$i])) {
-				StatusMessage("ERROR", "A required PHP extension is missing!", $extList[$i]);
-				echo "<br>";
+		if (!empty($config_object)) {
+			// check extensions
+			$extList = getRequiredExtensions();
+			for ($i = 0; $i < sizeof($extList); $i++) {
+				if (!extension_loaded($extList[$i])) {
+					StatusMessage("ERROR", "A required PHP extension is missing!", $extList[$i]);
+					echo "<br>";
+				}
 			}
-		}
-		// check TLS
-		$useTLS = $config_object->getUseTLS();
-		if (isset($useTLS) && ($useTLS == "yes")) {
-			if (!function_exists('ldap_start_tls')) {
-				StatusMessage("ERROR", "Your PHP installation does not support TLS encryption!");
-				echo "<br>";
+			// check TLS
+			$useTLS = $config_object->getUseTLS();
+			if (isset($useTLS) && ($useTLS == "yes")) {
+				if (!function_exists('ldap_start_tls')) {
+					StatusMessage("ERROR", "Your PHP installation does not support TLS encryption!");
+					echo "<br>";
+				}
 			}
 		}
 		// check if session expired
@@ -267,10 +292,11 @@ function display_LoginPage($config_object) {
 			StatusMessage("INFO", _("Your settings were successfully saved."), htmlspecialchars($_GET['selfserviceSaveOk']));
 			echo "<br>";
 		}
+		if (!empty($config_object)) {
 		?>
 		<br><br>
 		<div style="position:relative; z-index:5;">
-		<table width="650" align="center" border="2" rules="none" bgcolor="white">
+		<table width="650" align="center" border="2" rules="none" bgcolor="white" class="ui-corner-all">
 			<tr>
 				<td style="border-style:none" width="70" rowspan="2">
 					<img src="../graphics/lam.png" alt="Logo" style="margin-top: 5px; margin-bottom: 5px;">
@@ -405,6 +431,9 @@ function display_LoginPage($config_object) {
 			</tr>
 		</table>
 		</div>
+		<?php
+		}
+		?>
 		<br><br>
 			<TABLE style="position:absolute; bottom:10px;" border="0" width="99%">
 				<tr><td colspan=2><HR></td></tr>
@@ -560,6 +589,6 @@ if(!empty($_POST['checklogin'])) {
 	}
 }
 
+//displays the login window
 display_LoginPage($_SESSION["config"]);
-
 ?>
