@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: main_header.php,v 1.67 2012/08/18 15:53:52 gruberroland Exp $
+$Id: main_header.php,v 1.69 2013/01/01 20:46:28 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2011  Roland Gruber
+  Copyright (C) 2003 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -51,8 +51,16 @@ echo "<title>LDAP Account Manager" . $pro . " (" . str_replace(array('ldap://',
 // include all CSS files
 $cssDirName = dirname(__FILE__) . '/../style';
 $cssDir = dir($cssDirName);
-while ($cssEntry = $cssDir->read()) {
-	if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+$cssFiles = array();
+$cssEntry = $cssDir->read();
+while ($cssEntry !== false) {
+	if (substr($cssEntry, strlen($cssEntry) - 4, 4) == '.css') {
+		$cssFiles[] = $cssEntry;
+	}
+	$cssEntry = $cssDir->read();
+}
+sort($cssFiles);
+foreach ($cssFiles as $cssEntry) {
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"" . $headerPrefix . "../style/" . $cssEntry . "\">\n";
 }
 
@@ -192,6 +200,9 @@ jQuery(document).ready(function() {
 	<?php
 		$linkList = array();
 		for ($i = 0; $i < sizeof($types); $i++) {
+			if (isAccountTypeHidden($types[$i])) {
+				continue;
+			}
 			$link = '<a href="' . $headerPrefix . 'lists/list.php?type=' . $types[$i] .
 				'" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">' .
 				'<img height="16" width="16" alt="' . $types[$i] . '" src="' . $headerPrefix . '../graphics/' . $types[$i] . '.png">&nbsp;' .
