@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: massBuildAccounts.php,v 1.28 2012/08/13 17:43:48 gruberroland Exp $
+$Id: massBuildAccounts.php,v 1.29 2013/01/01 20:46:28 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2004 - 2012  Roland Gruber
@@ -91,6 +91,13 @@ if (isset($_GET['showldif'])) {
 
 include 'main_header.php';
 $scope = htmlspecialchars($_POST['scope']);
+
+// check if account type is ok
+if (isAccountTypeHidden($scope)) {
+	logNewMessage(LOG_ERR, 'User tried to access hidden upload: ' . $scope);
+	die();
+}
+
 echo '<div class="' . $scope . 'list-bright smallPaddingContent">';
 
 $selectedModules = explode(',', $_POST['selectedModules']);
