@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: massDoUpload.php,v 1.31 2012/08/15 18:24:46 gruberroland Exp $
+$Id: massDoUpload.php,v 1.33 2013/01/01 20:46:28 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2004 - 2012  Roland Gruber
@@ -62,6 +62,13 @@ setlanguage();
 
 include 'main_header.php';
 $scope = htmlspecialchars($_SESSION['mass_scope']);
+
+// check if account type is ok
+if (isAccountTypeHidden($scope)) {
+	logNewMessage(LOG_ERR, 'User tried to access hidden upload: ' . $scope);
+	die();
+}
+
 echo '<div class="' . $scope . 'list-bright smallPaddingContent">';
 
 // create accounts
@@ -98,15 +105,32 @@ if (($_SESSION['mass_counter'] < sizeof($accounts)) || !isset($_SESSION['mass_po
 				unset($attrs[$key]);
 			}
 		}
-		$success = @ldap_add($_SESSION['ldap']->server(), $dn, $attrs);
-		if (!$success) {
-			$errorMessage = array(
-				"ERROR",
-				_("LAM was unable to create account %s! An LDAP error occured."),
-				ldap_errno($_SESSION['ldap']->server()) . ": " . ldap_error($_SESSION['ldap']->server()),
-				array($_SESSION['mass_counter']));
-			$_SESSION['mass_errors'][] = $errorMessage;
-			$_SESSION['mass_failed'][] = $_SESSION['mass_counter'];
+		// run preactions
+		$preAttributes = array();
+		foreach ($attrs as $key => $value) {
+			$preAttributes[$key] = &$attrs[$key];
+		}
+		$preAttributes['dn'] = &$dn;
+		$preMessages = doUploadPreActions($scope, $_SESSION['mass_selectedModules'], $preAttributes);
+		$preActionOk = true;
+		for ($i = 0; $i < sizeof($preMessages); $i++) {
+			if (($preMessages[$i][0] == 'ERROR') || ($preMessages[$i][0] == 'WARN')) {
+				$preActionOk = false;
+				$_SESSION['mass_errors'][] = $preMessages[$i];
+			}
+		}
+		if ($preActionOk) {
+			// add LDAP entry
+			$success = @ldap_add($_SESSION['ldap']->server(), $dn, $attrs);
+			if (!$success) {
+				$errorMessage = array(
+					"ERROR",
+					_("LAM was unable to create account %s! An LDAP error occured."),
+					ldap_errno($_SESSION['ldap']->server()) . ": " . ldap_error($_SESSION['ldap']->server()),
+					array($_SESSION['mass_counter']));
+				$_SESSION['mass_errors'][] = $errorMessage;
+				$_SESSION['mass_failed'][] = $_SESSION['mass_counter'];
+			}
 		}
 		$_SESSION['mass_counter']++;
 	}
