@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: ajax.php,v 1.3 2012/02/25 18:39:52 gruberroland Exp $
+$Id: ajax.php,v 1.4 2012/11/25 17:01:44 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2011 - 2012  Roland Gruber
@@ -32,6 +32,10 @@ $Id: ajax.php,v 1.3 2012/02/25 18:39:52 gruberroland Exp $
 include_once("../../lib/security.inc");
 
 // start session
+if (isset($_GET['selfservice'])) {
+	// self service uses a different session name
+	session_name('SELFSERVICE');
+}
 startSecureSession();
 
 setlanguage();
