@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: pdfpage.php,v 1.46 2012/08/13 17:43:48 gruberroland Exp $
+$Id: pdfpage.php,v 1.47 2013/01/01 20:46:27 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-                2007 - 2010  Roland Gruber
+                2007 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -69,6 +69,11 @@ if(isset($_POST['type'])) {
 	}
 }
 
+if (isAccountTypeHidden($_GET['type'])) {
+	logNewMessage(LOG_ERR, 'User tried to access hidden PDF structure: ' . $_GET['type']);
+	die();
+}
+
 
 // Abort and go back to main pdf structure page
 if(isset($_GET['abort'])) {
