@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profilepage.php,v 1.50 2012/08/26 14:09:22 gruberroland Exp $
+$Id: profilepage.php,v 1.51 2013/01/01 20:46:28 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2010  Roland Gruber
+  Copyright (C) 2003 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -61,6 +61,11 @@ if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 if (isset($_POST['profname'])) $_GET['edit'] = $_POST['profname'];
 if (isset($_POST['accounttype'])) $_GET['type'] = $_POST['accounttype'];
 
+if (isAccountTypeHidden($_GET['type'])) {
+	logNewMessage(LOG_ERR, 'User tried to access hidden account type profile: ' . $_GET['type']);
+	die();
+}
+
 // abort button was pressed
 // back to profile editor
 if (isset($_POST['abort'])) {
