@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: lamdaemonTest.php,v 1.28 2012/07/22 10:37:00 gruberroland Exp $
+$Id: lamdaemonTest.php,v 1.29 2012/09/29 10:43:13 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2006 - 2012  Roland Gruber
@@ -195,6 +195,12 @@ function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota, $contai
 		$container->addElement(new htmlOutputText(_("No lamdaemon path set, please update your LAM configuration settings.")), true);
 		$stopTest = true;
 	}
+	elseif (substr($_SESSION['config']->get_scriptPath(), -3) != '.pl') {
+		$container->addElement(new htmlImage($failImage));
+		$container->addElement($spacer);
+		$container->addElement(new htmlOutputText(_("Lamdaemon path does not end with \".pl\". Did you enter the full path to the script?")), true);
+		$stopTest = true;
+	}
 	else {
 		$container->addElement(new htmlImage($okImage));
 		$container->addElement($spacer);
